@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.13;
+our $VERSION = 0.14;
 
 # Get XML.
 has xml => (
@@ -36,6 +36,7 @@ Map::Tube::Prague - Interface to the Prague Metro Map.
 =head1 SYNOPSIS
 
  use Map::Tube::Prague;
+
  my $obj = Map::Tube::Prague->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
  my $line = $obj->get_line_by_id($line_id);
@@ -218,6 +219,57 @@ For more information about Prague Map, click L<here|https://en.wikipedia.org/wik
  # Linka B
  # Linka C
 
+=head1 EXAMPLE5
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(encode_utf8);
+ use Map::Tube::Prague;
+
+ # Arguments.
+ if (@ARGV < 1) {
+         print STDERR "Usage: $0 line\n";
+         exit 1;
+ }
+ my $line = $ARGV[0];
+
+ # Object.
+ my $obj = Map::Tube::Prague->new;
+
+ # Get stations for line.
+ my $stations_ar = $obj->get_stations($line);
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } @{$stations_ar};
+
+ # Output:
+ # Usage: __PROG__ line
+
+ # Output with 'foo' argument.
+ # Map::Tube::get_stations(): ERROR: Invalid Line Name [foo]. (status: 105) file __PROG__ on line __LINE__
+
+ # Output with 'Linka A' argument.
+ # Nemocnice Motol
+ # Petřiny
+ # Nádraží Veleslavín
+ # Bořislavka
+ # Dejvická
+ # Hradčanská
+ # Malostranská
+ # Staroměstská
+ # Můstek
+ # Muzeum
+ # Náměstí Míru
+ # Jiřího z Poděbrad
+ # Flora
+ # Želivského
+ # Strašnická
+ # Skalka
+ # Depo Hostivař
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -249,18 +301,20 @@ L<https://github.com/tupinek/Map-Tube-Prague>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2015 Michal Špaček
- Artistic License
- BSD 2-Clause License
+© 2014-2020 Michal Josef Špaček
+
+Artistic License
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.13
+0.14
 
 =cut
